import logging


def disable_logging(logger_names, level=logging.WARNING):
    if isinstance(logger_names, str):
        logging.getLogger(logger_names).setLevel(level)
    elif isinstance(logger_names, (tuple, list)):
        for name in logger_names:
            logging.getLogger(name).setLevel(level)
    else:
        raise TypeError(f"Expected logger_names to be str, tuple or list, got "
                        f"{type(logger_names)} instead")


class LoggerMixin:
    def __init__(self):
        self.logger = logging.getLogger(self.logger_name)

    @property
    def logger_name(self):
        module_name = self.__module__
        if module_name == "__main__":
            import inspect
            module_name = os.path.splitext(os.path.basename(
                inspect.getfile(self.__class__)
            ))[0]
        return '{}.{}'.format(module_name, self.__class__.__name__)



import logging
from typing import Optional, Union


def get_simple_logger(
        name: Optional[str] = None,
        console: bool = True,
        log_level: Optional[Union[str, int]] = logging.DEBUG,
        log_file: Optional[str] = None):
    """
    Create instance of logger.
    :param name: Logger name
    :param log_level: Log level
    :param log_file: Log file path
    :param console: Output to console if True
    :return: logging.Logger
    """
    if isinstance(log_level, str):
        log_level = logging.getLevelName(log_level)
    log_formatter = logging.Formatter('%(asctime)s %(name)s %(levelname)s %(message)s')
    log_formatter.datefmt = "%Y-%m-%d %H:%M:%S"
    logger = logging.getLogger()
    if name is not None:
        logger.name = name
    logger.setLevel(log_level)
    if log_file:
        file_handler = logging.FileHandler(log_file, mode='a')
        file_handler.setFormatter(log_formatter)
        logger.addHandler(file_handler)

    if console:
        console_handler = logging.StreamHandler()
        console_handler.setLevel(log_level)
        console_handler.setFormatter(log_formatter)
        logger.addHandler(console_handler)
    return logger



from setuptools import setup, find_packages
from os import path

here = path.abspath(path.dirname(__file__))

# Get the long description from the README file
with open(path.join(here, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()

# Arguments marked as "Required" below must be included for upload to PyPI.
# Fields marked as "Optional" may be commented out.

setup(
    name='enlog',
    version='0.1.0',
    description='Tool to simplify python logging initialization',
    long_description=long_description,
    long_description_content_type='text/markdown',

    # This should be a valid link to your project's main homepage.
    #
    # This field corresponds to the "Home-Page" metadata field:
    # https://packaging.python.org/specifications/core-metadata/#home-page-optional
    # url='https://github.com/pypa/sampleproject',  # Optional
    author='Aleksey Osadshuk',
    author_email='osdalex@gmail.com',
    classifiers=[  # Optional
        # How mature is this project? Common values are
        #   3 - Alpha
        #   4 - Beta
        #   5 - Production/Stable
        'Development Status :: 3 - Alpha',

        # Indicate who your project is intended for
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',

        # Pick your license as you wish
        'License :: OSI Approved :: MIT License',

        # Specify the Python versions you support here. In particular, ensure
        # that you indicate you support Python 3. These classifiers are *not*
        # checked by 'pip install'. See instead 'python_requires' below.
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3 :: Only',
    ],
    keywords='simple logging',
    packages=find_packages(exclude=['contrib', 'docs', 'tests']),
    python_requires='>=3.5, <4',
    extras_require={  # Optional
        'dev': ['check-manifest'],
        'test': ['coverage'],
    },

    # List additional URLs that are relevant to your project as a dict.
    #
    # This field corresponds to the "Project-URL" metadata fields:
    # https://packaging.python.org/specifications/core-metadata/#project-url-multiple-use
    #
    # Examples listed include a pattern for specifying where the package tracks
    # issues, where the source is hosted, where to say thanks to the package
    # maintainers, and where to support the project financially. The key is
    # what's used to render the link text on PyPI.
    project_urls={  # Optional
        'Bug Reports': 'https://github.com/pypa/sampleproject/issues',
        'Funding': 'https://donate.pypi.org',
        'Say Thanks!': 'http://saythanks.io/to/example',
        'Source': 'https://github.com/pypa/sampleproject/',
    },
)
